@@ -49,7 +49,6 @@
 
 package com.openexchange.xing.json;
 
-import java.util.Collection;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
@@ -118,10 +117,4 @@ public class XingActionFactory implements AJAXActionServiceFactory {
     public AJAXActionService createActionService(final String action) throws OXException {
         return actions.get(action);
     }
-
-    @Override
-    public Collection<? extends AJAXActionService> getSupportedServices() {
-        return java.util.Collections.unmodifiableCollection(actions.values());
-    }
-
 }
